Sports and Pop Culture from Bill Simmons and our rotating cast of writers – Grantland «
Description: Sports and Pop Culture from Bill Simmons and our rotating cast of writers | Grantland

## MLB Trade Value, Part 2

With the hot stove smoking and the winter meetings looming, we conclude our annual ranking of baseball’s 50 most valuable assets.

by Jonah Keri

- NBA

  ## How Mike Miller Became the Trusted Confidant of LeBron James

  by Jonathan Abrams

- NFL

  ## Make It or Break It: The NFL Players Who Have Everything to Prove in December

  by Bill Barnwell

## The Latest

- ### Championship Weekend Preview

  TCU vs. Baylor, FSU vs. America, and more key college football storylines.

  by Matt Hinton

- ### Giveaway Eagles: Should Philadelphia Be Worried About Its Turnover Problem?

- ### The NHL’s Great Connor McDavid Sweepstakes

- ### 30 for 30 Shorts: Ali-Norton III and a Profound Protest

- ### Who Has the Upper Hand? Beyoncé vs. Solange

  Sister vs. Sister. Who's on top?

  by Rembert Browne, Shea Serrano and Juliet Litman

- ### Straight Outta Locash: ‘Top Five,’ ‘CB4,’ and Chris Rock’s Movie Misadventures

- ### A Conversation With Chris Rock About Rap, Comedy, and Cosby

- ### The Week in Gossip: Kanye Grinches Kardashian Khristmas, Taylor Bans a Victoria’s Secret Model

- ### CM Punk’s Parting Shot

  The absent superstar's hard hard truths about the WWE.

  by The Masked Man

- ### What We Saw in 2014: Ray Rice, Janay Palmer, and the Tape

- ### Titus’s Top 12 NCAA Power Rankings: Guess Who’s No. 1

- ### ‘B.S. Report’: Chuck Klosterman

- ## NBA Shootaround: So This Is What Winning Feels Like

  by Grantland Staff

- ## The Browns Starting Brian Hoyer Is Smart (Which Is Crazy)

  by Andrew Sharp

- ## We Went There: Wisconsin-Duke at the Kohl Center

  by Mark Titus

- ## The ‘Terminator: Genisys’ Trailer Is Out. We Have Just a Few Questions. (We Have a Lot of Questions.)

  by Chris Ryan and Mark Lisanti

- ## The Godfather of What We Find Funny: Robert Downey Sr. Gets a Film Festival

  by Sean Witzke

- ## Did Kevin From ‘Home Alone’ Grow Up to Be Jigsaw? A Deadly Serious Investigation

  by Jason Concepcion

## More movies

- ### The ‘Terminator: Genisys’ Trailer Is Out. We Have Just a Few Questions. (We Have a Lot of Questions.)

- ### The Godfather of What We Find Funny: Robert Downey Sr. Gets a Film Festival

- ### Did Kevin From ‘Home Alone’ Grow Up to Be Jigsaw? A Deadly Serious Investigation

- ### Straight Outta Locash: ‘Top Five,’ ‘CB4,’ and Chris Rock’s Movie Misadventures

- ### 2014 Is Totally the Year of Drummers

### The Weight of Guilt: Inside the World of Competitive Bass Fishing Cheaters

by David Hill

> In the spring of 1984, Danny Ray Davis caught an 8.7-pound bass in the KYKX Big Bass Classic. It wasn’t big enough to stuff and mount on the wall, but it was big enough to qualify for the $105,000 first prize. Winning two major bass fishing tournaments in less than a year? He was lucky. He was ecstatic. He was in deep shit.

- B.S. Report

  ### Andy Greenwald on ‘The Walking Dead’ and ‘Homeland’

- The Lowe Post

  ### Chris Herrington and Ethan Sherwood Strauss on the Grizzlies and Warriors

- B.S. Report

  ### Don Van Natta Jr. Analyzes the Ray Rice Scandal

## Podcasts

### The B.S. Report

- #### Chuck Klosterman

  December 4, 2014

  Chuck Klosterman and Bill Simmons discuss college football, Bruce Springsteen and Chris Martin fronting U2, the role of a sports commissioner, and much more.

- #### Andy Greenwald and Joe House

  December 3, 2014

  Grantland’s Andy Greenwald joins the B.S. Report to discuss ‘The Walking Dead,’ ‘The Missing,’ and ‘Homeland.’ Plus, Joe House calls in to talk basketball.

More The B.S. Report Podcasts

### Grantland Sports

- #### The Grantland NFL Podcast

  December 4, 2014

  Mays and Barnwell adopt the Falcons and discuss the league’s rookie quarterbacks on today’s podcast.

- #### The Lowe Post – Herrington and Strauss

  December 3, 2014

  Zach talks to Chris Herrington of the ‘Memphis Commercial Appeal’ and Ethan Sherwood Strauss of ESPN.com about the league’s two hottest teams.

More Grantland Sports Podcasts

### Grantland Pop Culture

- #### Rembert Explains – Wesley Morris

  December 4, 2014

  Rembert Browne and Grantland’s own Wesley Morris spontaneously sit down to talk about their Cosby piece, drama over Thanksgiving, and Barack Obama.

- #### The Moment – Killer Mike

  December 3, 2014

  Killer Mike, one half of Run The Jewels, on his duty as an artist to take risks, creatively and as a leader.

More Grantland Pop Culture Podcasts